@@ -26,7 +26,7 @@
 ##  shiela-install.sh: repository install program (syntax: Bourne-Shell)
 ##
 
-version="1.1.0"
+version="1.1.1"
 
 prefix="@prefix@"
 bindir="@bindir@"
@@ -103,7 +103,8 @@ not immediately correct.
 
 EOT
 
-for arg; do
+for arg
+do
     eval `echo "$arg" | sed -e 's/^\([^=]*\)=\(.*\)$/V_\1="\2"/'`
 done
 
